import random


def quicksort(nums):
    if len(nums) <= 1:
        return nums
    else:
        q = random.choice(nums)
    l_nums = [n for n in nums if n < q]

    e_nums = [q] * nums.count(q)
    b_nums = [n for n in nums if n > q]
    return quicksort(l_nums) + e_nums + quicksort(b_nums)


def main():
    arr = [10, 7, 8, 9, 1, 5]
    print("Sorted array is:")
    print(quicksort(arr))


if __name__ == '__main__':
    main()



import os
from random import randint
import multiprocessing


def generate_combination(start, end, step, count):
    for i in range(start, end, step):
        for j in range(count):
            yield i, j


def gen_data(start: int, end: int, step: int, count: int):
    os.makedirs('./tragic_semester_work_2/load_testing_data', exist_ok=True)
    for i in range(start, end, step):
        with multiprocessing.Pool(multiprocessing.cpu_count()) as p:
            p.starmap(writing, generate_combination(start, end, step, count))


def writing(i, j):
    with open(f'./tragic_semester_work_2/load_testing_data/{i}_{j + 1}.txt', 'w') as file:
        mass = [randint(-10000000, 100000000) for _ in range(i)]
        for number in mass:
            file.write(f'{number} ')


def main():
    a = [int(i) for i in input().split()]
    gen_data(a[0], a[1], a[2], a[3])

    # a[0] - start - a[0] + a[1] - здесь мы ходим и номер каждого шага обозначает кол-во элементов в нашем массиве
    # a[1] - end
    # a[2] - step
    # a[3] - count - количество массивов на каждой ступеньке


if __name__ == '__main__':
    main()



import time
import os
import re
import datetime
import matplotlib.pyplot as plt
import pandas as pd
from tragic_semester_work_2.quicksort import quicksort
from tragic_semester_work_2.counts_sort import SimpleCountingSort
from collections import defaultdict
import csv
from pathlib import Path


# Принимает название сортировки
def measure_times(pathing):
    os.makedirs('./tragic_semester_work_2/load_testing_measurements', exist_ok=True)
    if pathing == 'quick_sort':
        sort_func = quicksort
    elif pathing == 'counting_sort':
        sort_func = SimpleCountingSort
    else:
        print('ТЫ ЧО ВВЁЛ, А?')
        return

    dict_sheets = defaultdict(list)
    list_txt_name = os.listdir(Path("tragic_semester_work_2") / 'load_testing_data')

    for index in range(len(list_txt_name)):
        # Достаём размерность массива и номер массива\
        list_txt = re.split('[_.]', list_txt_name[index][:])
        current_size, number_test = list_txt[0], list_txt[1]

        with open(Path("tragic_semester_work_2") / 'load_testing_data' / f'{current_size}_{number_test}.txt') as file:
            a = file.read()
            arr = [int(num) for num in a.split()]

        start = time.time()
        sort_func(arr)
        end = time.time() - start
        dict_sheets[current_size].append(end)
    return dict_creation(dict_sheets)


# Делает csv файл
def dict_creation(dict_sheets):
    name = int(datetime.datetime.now().timestamp())
    with open(Path("tragic_semester_work_2") / 'load_testing_measurements' / f'{name}.csv', mode='a',
              encoding='utf-8') as w_file:
        file_writer = csv.writer(w_file, delimiter=",", lineterminator="\r")
        file_writer.writerow(["size", "min", "max", "avg", "median"])
    for key, value in dict_sheets.items():
        mas = sorted(value[:])
        with open(Path("tragic_semester_work_2") / 'load_testing_measurements' / f'{name}.csv', mode="a",
                  encoding='utf-8') as w_file:
            file_writer = csv.writer(w_file, delimiter=",", lineterminator="\r")
            file_writer.writerow([key, mas[0], mas[-1], sum(i for i in mas) / len(mas), mas[len(mas) // 2]])

    return name


# Рисуем график
def create_graph(csv_file_path: str):
    try:
        os.makedirs('./tragic_semester_work_2/load_testing_plots', exist_ok=True)
        data = pd.read_csv(Path("tragic_semester_work_2") / 'load_testing_measurements' / f"{csv_file_path}.csv")
        data.set_index("size", inplace=True)
        data.head()
        data.plot()
        plt.savefig(
            Path("tragic_semester_work_2") / 'load_testing_plots' / f'{int(datetime.datetime.now().timestamp())}.jpg')
    except Exception as e:
        print(e)
        print('Кароч, он тебе там какую-то хрень написал наверное. Я так думаю, что ты просто послушал, то что я '
              'говорил тебе и написал фигню, чтобы график не строился. Красавчик!👍')


def main():
    path = input('quick_sort or counting_sort\n')
    name_csv = measure_times(path)
    create_graph(str(name_csv))
    # output_dict = measure_time(path)
    # dict_creation(output_dict)
    # path_csv = input('Если хотите увидеть график, то введите сюда название файлика csv без .csv '
    #                  'А если не хотите, ну это ваши проблемы, напишите сюда какую-то хрень\n')
    # create_chart(path_csv)


if __name__ == '__main__':
    main()



def SimpleCountingSort(arr):
    scope = max(arr) + 1
    C = [0] * scope
    minus_scope = abs(min(arr)) + 1
    B = [0] * minus_scope
    for x in arr:
        if x >= 0:
            C[x] += 1
        else:
            B[abs(x)] += 1
    arr[:] = []
    for number in range(minus_scope):
        arr += [-number] * B[number]
    arr.reverse()
    for number in range(scope):
        arr += [number] * C[number]
    return arr


def main():
    print(SimpleCountingSort([30220180, 11897874, 30485241, 98895363, 35071568, 49460507, 98676250, 63229133, -6510118, 13017380, 33097017, 19719663]))


if __name__ == '__main__':
    main()



import click
from tragic_semester_work_2.Generator import gen_data
from tragic_semester_work_2.Time import measure_times, create_graph


@click.group()
def main():
    pass


@main.command()
@click.option('--start', type=int, default=1)
@click.option('--end', type=int, default=10)
@click.option('--step', type=int, default=1)
@click.option('--count', type=int, default=1)
def generate_data(start: int, end: int, step: int, count: int):
    if start > end:
        print('Чел ты херню ввёл')
    else:
        gen_data(start, end, step, count)


@main.command()
# Вот здесь КАРОЧ напишите название сортировки quick_sort or counting_sort
@click.option('--name_sort', type=str, default='quick_sort')
def measure_time(name_sort: str):
    #  ДА НУ ИДИ ТЫ НАФИГ КАКИЕ ЕЩЁ ЭКСТРА АРГУМЕНТЫ НЕОЖИДАННЫЕ, ТАМ ВСЁ ВПОЛНЕ ОЖИДАЕМО БЫЛО
    try:
        measure_times(name_sort)
    except Exception as e:
        print(e)
        print('Ладно давай я тебе проще скажу, посмотри на то что ты ввёл сюда')


@main.command()
@click.option('--file', type=str, default='1621659210')
def create_chart(file: str):
    try:
        create_graph(file)
    except Exception as e:
        print(e)
        print('Ладно давай я тебе проще скажу, посмотри на то что ты ввёл сюда')


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tragic_semester_work_2']

package_data = \
{'': ['*'],
 'tragic_semester_work_2': ['load_testing_data/*',
                            'load_testing_measurements/*',
                            'load_testing_plots/*']}

install_requires = \
['click>=8.0.1,<9.0.0']

entry_points = \
{'console_scripts': ['tragic_semester_work_2 = '
                     'tragic_semester_work_2.main:main']}

setup_kwargs = {
    'name': 'tragic-semester-work-2',
    'version': '0.1.6',
    'description': '',
    'long_description': None,
    'author': 'Пётр Куркин',
    'author_email': 'kurkin801@mail.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
